==> kubernetes-model-admissionregistration-5.9.0-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SelfSubjectRulesReviewBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SelfSubjectRulesReviewBuilder extends io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview,io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewBuilder>{
  public SelfSubjectRulesReviewBuilder() {
    this(false);
  }
  public SelfSubjectRulesReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new SelfSubjectRulesReview(), validationEnabled);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SelfSubjectRulesReview(), validationEnabled);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance) {
    this(fluent, instance, false);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance) {
    this(instance,false);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview build() {
    SelfSubjectRulesReview buildable = new SelfSubjectRulesReview(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelfSubjectRulesReviewBuilder that = (SelfSubjectRulesReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-admissionregistration-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/authorization/v1/SelfSubjectRulesReviewBuilder.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SelfSubjectRulesReviewBuilder extends io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluentImpl<io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview,io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewBuilder>{
  public SelfSubjectRulesReviewBuilder() {
    this(false);
  }
  public SelfSubjectRulesReviewBuilder(java.lang.Boolean validationEnabled) {
    this(new SelfSubjectRulesReview(), validationEnabled);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent) {
    this(fluent, false);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SelfSubjectRulesReview(), validationEnabled);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance) {
    this(fluent, instance, false);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent,io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance) {
    this(instance,false);
  }
  public SelfSubjectRulesReviewBuilder(io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReviewFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.authorization.v1.SelfSubjectRulesReview build() {
    SelfSubjectRulesReview buildable = new SelfSubjectRulesReview(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelfSubjectRulesReviewBuilder that = (SelfSubjectRulesReviewBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
